@@ -19,7 +19,7 @@
  *
  * Inspired by nsyslog, originally written by Darren Reed.
  *
- * $Id: sources.c,v 1.37.4.5 2005/02/03 11:08:11 bazsi Exp $
+ * $Id: sources.c,v 1.37.4.7 2005/05/25 08:29:29 bazsi Exp $
  *
  ***************************************************************************/
 
@@ -85,7 +85,7 @@ do_read_line(struct read_handler **h,
 	UINT32 length;
 	int n;
 	char sabuf[256];
-	size_t salen = sizeof(sabuf);
+	socklen_t salen = sizeof(sabuf);
 
 	if (!closure->dgram) {
 		if (closure->pad_size)
@@ -229,6 +229,13 @@ static struct ol_string *get_source_hostname(struct address_info *a, int usedns,
 			if (usefqdn) {
 				gethostname(buf, sizeof(buf) - 1);
 				buf[127] = 0;
+				// Check if hostname includes a . else do an fqdn lookup
+				if (strchr(buf, '.') == NULL) {
+					struct hostent *result = gethostbyname(buf);
+					if (result) {
+						strncpy(buf, result->h_name, sizeof(buf) - 1);
+					}
+				}
 			}
 			else {
 				getshorthostname(buf, sizeof(buf));
